@@ -75,9 +75,16 @@ sub parse_element {
     $element =~ /
         ^\s*                            # skip leading whitespace
         (                               # package name or substvar (1)
-         [a-zA-Z0-9][a-zA-Z0-9+.-]+     #   package name
-         |                              #   or
-         \$\{[a-zA-Z0-9:-]+\}           #   substvar
+         (?:                            #  start of the name
+          [a-zA-Z0-9][a-zA-Z0-9+.-]+    #   start of a package name
+          |                             #   or
+          \$\{[a-zA-Z0-9:-]+\}          #   substvar
+         )                              #  end of start of the name
+         (?:                            #  substvars may be mixed in
+          [a-zA-Z0-9+.-]+               #   package name portion
+          |                             #   or
+          \$\{[a-zA-Z0-9:-]+\}          #   substvar
+         )*                             #  zero or more portions or substvars
         )                               # end of package name or substvar
         (?:                             # start of optional version
          \s* \(                         # open parenthesis for version part
